# coding: utf-8

"""
    Yanport API

    ## À propos Voici quelques ressources qui vous aideront à explorer notre API, si vous avez des problèmes ou des demandes, veuillez contacter le [support](mailto:support@yanport.com). ## REST API Nos services webs utilisent le protocle **HTTPS** sur le port 443, tout accès en HTTP sur le port 80 est bloqué par notre pare-feu. Les échanges de données sont réalisés en **JSON**. ## Authentification Avant de commencer à explorer notre API, vous devez nous [contacter](https://www.yanport.com/contact) afin d'obtenir un [JSON Web Token](https://jwt.io) (**JWT**) qui vous permettra de vous identifier à chaque requêtes. ### JWT (header) La méthode privilégiée pour s'authentifier est de passer à chaque requêtes le token dans le header `Authorization: Bearer {{ JWT }}` en remplaçant `{{ JWT }}` par votre token. ### JWT (query param) Il est aussi possible de passer le token directement en query param de la requête `https://api.yanport.com/?token={{ JWT }}`. (_privilégié le passage par header en production._) ## Pour démarrer Lorsque vous disposez de votre token d'authentification, vous pouvez commencer à explorer notre API grâce au boutton  `Try it out` sur chacun de nos webs services. Mais au préalable, vous devez vous authentifier en cliquant sur le boutton `Authorize `, en remplissant l'input `api_key` avec `Bearer {{ JWT }}`.  **Exemple** `Bearer eyUEkiLCJh...CHCUiBfD63oxoo=` ## Limitation Toutes les requêtes à notre API sont loggées, c'est pourquoi vous devez respecter nos [CGU](https://dev.yanport.com/cgu) afin d'éviter tout usage abusif de notre API. 

    OpenAPI spec version: 1.0
    Contact: dev@yanport.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class MandataryNetwork(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'name': 'str',
        'description': 'str',
        'siren': 'str',
        'siret': 'str',
        'address': 'Address',
        'phone': 'str',
        'email': 'str',
        'url': 'str',
        'image_url': 'str',
        'active': 'bool'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'description': 'description',
        'siren': 'siren',
        'siret': 'siret',
        'address': 'address',
        'phone': 'phone',
        'email': 'email',
        'url': 'url',
        'image_url': 'imageUrl',
        'active': 'active'
    }

    def __init__(self, id=None, name=None, description=None, siren=None, siret=None, address=None, phone=None, email=None, url=None, image_url=None, active=None):
        """
        MandataryNetwork - a model defined in Swagger
        """

        self._id = None
        self._name = None
        self._description = None
        self._siren = None
        self._siret = None
        self._address = None
        self._phone = None
        self._email = None
        self._url = None
        self._image_url = None
        self._active = None

        if id is not None:
          self.id = id
        if name is not None:
          self.name = name
        if description is not None:
          self.description = description
        if siren is not None:
          self.siren = siren
        if siret is not None:
          self.siret = siret
        if address is not None:
          self.address = address
        if phone is not None:
          self.phone = phone
        if email is not None:
          self.email = email
        if url is not None:
          self.url = url
        if image_url is not None:
          self.image_url = image_url
        if active is not None:
          self.active = active

    @property
    def id(self):
        """
        Gets the id of this MandataryNetwork.

        :return: The id of this MandataryNetwork.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this MandataryNetwork.

        :param id: The id of this MandataryNetwork.
        :type: int
        """

        self._id = id

    @property
    def name(self):
        """
        Gets the name of this MandataryNetwork.

        :return: The name of this MandataryNetwork.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this MandataryNetwork.

        :param name: The name of this MandataryNetwork.
        :type: str
        """

        self._name = name

    @property
    def description(self):
        """
        Gets the description of this MandataryNetwork.

        :return: The description of this MandataryNetwork.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this MandataryNetwork.

        :param description: The description of this MandataryNetwork.
        :type: str
        """

        self._description = description

    @property
    def siren(self):
        """
        Gets the siren of this MandataryNetwork.

        :return: The siren of this MandataryNetwork.
        :rtype: str
        """
        return self._siren

    @siren.setter
    def siren(self, siren):
        """
        Sets the siren of this MandataryNetwork.

        :param siren: The siren of this MandataryNetwork.
        :type: str
        """

        self._siren = siren

    @property
    def siret(self):
        """
        Gets the siret of this MandataryNetwork.

        :return: The siret of this MandataryNetwork.
        :rtype: str
        """
        return self._siret

    @siret.setter
    def siret(self, siret):
        """
        Sets the siret of this MandataryNetwork.

        :param siret: The siret of this MandataryNetwork.
        :type: str
        """

        self._siret = siret

    @property
    def address(self):
        """
        Gets the address of this MandataryNetwork.

        :return: The address of this MandataryNetwork.
        :rtype: Address
        """
        return self._address

    @address.setter
    def address(self, address):
        """
        Sets the address of this MandataryNetwork.

        :param address: The address of this MandataryNetwork.
        :type: Address
        """

        self._address = address

    @property
    def phone(self):
        """
        Gets the phone of this MandataryNetwork.

        :return: The phone of this MandataryNetwork.
        :rtype: str
        """
        return self._phone

    @phone.setter
    def phone(self, phone):
        """
        Sets the phone of this MandataryNetwork.

        :param phone: The phone of this MandataryNetwork.
        :type: str
        """

        self._phone = phone

    @property
    def email(self):
        """
        Gets the email of this MandataryNetwork.

        :return: The email of this MandataryNetwork.
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """
        Sets the email of this MandataryNetwork.

        :param email: The email of this MandataryNetwork.
        :type: str
        """

        self._email = email

    @property
    def url(self):
        """
        Gets the url of this MandataryNetwork.

        :return: The url of this MandataryNetwork.
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """
        Sets the url of this MandataryNetwork.

        :param url: The url of this MandataryNetwork.
        :type: str
        """

        self._url = url

    @property
    def image_url(self):
        """
        Gets the image_url of this MandataryNetwork.

        :return: The image_url of this MandataryNetwork.
        :rtype: str
        """
        return self._image_url

    @image_url.setter
    def image_url(self, image_url):
        """
        Sets the image_url of this MandataryNetwork.

        :param image_url: The image_url of this MandataryNetwork.
        :type: str
        """

        self._image_url = image_url

    @property
    def active(self):
        """
        Gets the active of this MandataryNetwork.

        :return: The active of this MandataryNetwork.
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """
        Sets the active of this MandataryNetwork.

        :param active: The active of this MandataryNetwork.
        :type: bool
        """

        self._active = active

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, MandataryNetwork):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
