# coding: utf-8

"""
    Yanport API

    ## À propos Voici quelques ressources qui vous aideront à explorer notre API, si vous avez des problèmes ou des demandes, veuillez contacter le [support](mailto:support@yanport.com). ## REST API Nos services webs utilisent le protocle **HTTPS** sur le port 443, tout accès en HTTP sur le port 80 est bloqué par notre pare-feu. Les échanges de données sont réalisés en **JSON**. ## Authentification Avant de commencer à explorer notre API, vous devez nous [contacter](https://www.yanport.com/contact) afin d'obtenir un [JSON Web Token](https://jwt.io) (**JWT**) qui vous permettra de vous identifier à chaque requêtes. ### JWT (header) La méthode privilégiée pour s'authentifier est de passer à chaque requêtes le token dans le header `Authorization: Bearer {{ JWT }}` en remplaçant `{{ JWT }}` par votre token. ### JWT (query param) Il est aussi possible de passer le token directement en query param de la requête `https://api.yanport.com/?token={{ JWT }}`. (_privilégié le passage par header en production._) ## Pour démarrer Lorsque vous disposez de votre token d'authentification, vous pouvez commencer à explorer notre API grâce au boutton  `Try it out` sur chacun de nos webs services. Mais au préalable, vous devez vous authentifier en cliquant sur le boutton `Authorize `, en remplissant l'input `api_key` avec `Bearer {{ JWT }}`.  **Exemple** `Bearer eyUEkiLCJh...CHCUiBfD63oxoo=` ## Limitation Toutes les requêtes à notre API sont loggées, c'est pourquoi vous devez respecter nos [CGU](https://dev.yanport.com/cgu) afin d'éviter tout usage abusif de notre API. 

    OpenAPI spec version: 1.0
    Contact: dev@yanport.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into sdk package
from .models.ad import Ad
from .models.ad_ref import AdRef
from .models.address import Address
from .models.agency import Agency
from .models.agency_naf_code import AgencyNafCode
from .models.body import Body
from .models.body_1 import Body1
from .models.body_2 import Body2
from .models.bound_type import BoundType
from .models.building import Building
from .models.city import City
from .models.count_response import CountResponse
from .models.crawl_source import CrawlSource
from .models.customer import Customer
from .models.date_histogram import DateHistogram
from .models.date_histogram_point import DateHistogramPoint
from .models.dealer_sub_type import DealerSubType
from .models.dealer_type import DealerType
from .models.default_response import DefaultResponse
from .models.event_type import EventType
from .models.histogram import Histogram
from .models.histogram_point import HistogramPoint
from .models.inline_response_200 import InlineResponse200
from .models.inline_response_200_1 import InlineResponse2001
from .models.inline_response_200_2 import InlineResponse2002
from .models.inline_response_200_3 import InlineResponse2003
from .models.inline_response_200_4 import InlineResponse2004
from .models.inline_response_200_5 import InlineResponse2005
from .models.inline_response_200_6 import InlineResponse2006
from .models.inline_response_200_7 import InlineResponse2007
from .models.iris_quarter import IrisQuarter
from .models.lng_lat import LngLat
from .models.location import Location
from .models.mandatary_network import MandataryNetwork
from .models.marketing_dealer import MarketingDealer
from .models.marketing_type import MarketingType
from .models.model_property import ModelProperty
from .models.percentiles import Percentiles
from .models.percentiles_values import PercentilesValues
from .models.price_event import PriceEvent
from .models.property_building import PropertyBuilding
from .models.property_features import PropertyFeatures
from .models.property_features_additional_features import PropertyFeaturesAdditionalFeatures
from .models.property_features_condominium import PropertyFeaturesCondominium
from .models.property_features_construction import PropertyFeaturesConstruction
from .models.property_features_descriptive import PropertyFeaturesDescriptive
from .models.property_features_descriptive_equipments import PropertyFeaturesDescriptiveEquipments
from .models.property_features_descriptive_services import PropertyFeaturesDescriptiveServices
from .models.property_features_energy import PropertyFeaturesEnergy
from .models.property_features_geometry import PropertyFeaturesGeometry
from .models.property_features_geometry_areas import PropertyFeaturesGeometryAreas
from .models.property_features_geometry_floors import PropertyFeaturesGeometryFloors
from .models.property_features_visual import PropertyFeaturesVisual
from .models.property_marketing import PropertyMarketing
from .models.property_search_query import PropertySearchQuery
from .models.property_type import PropertyType
from .models.range import Range
from .models.rent_control import RentControl
from .models.rent_control_result import RentControlResult
from .models.rent_control_status import RentControlStatus
from .models.rent_control_zone import RentControlZone
from .models.room import Room
from .models.search_query_param import SearchQueryParam
from .models.sections import Sections
from .models.sections_conclusion import SectionsConclusion
from .models.sections_estimation_engine import SectionsEstimationEngine
from .models.sections_estimation_engine_zones import SectionsEstimationEngineZones
from .models.sections_market_stats import SectionsMarketStats
from .models.sections_property_price_study import SectionsPropertyPriceStudy
from .models.sections_similar_properties import SectionsSimilarProperties
from .models.state import State
from .models.stats import Stats
from .models.stock_evolution import StockEvolution
from .models.stock_evolution_point import StockEvolutionPoint
from .models.study import Study
from .models.user import User
from .models.user_user_preference import UserUserPreference
from .models.user_user_preference_commercial_zone import UserUserPreferenceCommercialZone

# import apis into sdk package
from .apis.agences_api import AgencesApi
from .apis.annonces_api import AnnoncesApi
from .apis.biens_api import BiensApi
from .apis.bienssimilaires_api import BienssimilairesApi
from .apis.encadrementloyers_api import EncadrementloyersApi
from .apis.etudes_api import EtudesApi
from .apis.evenementsadbox_api import EvenementsadboxApi
from .apis.mandataires_api import MandatairesApi
from .apis.utilisateurs_api import UtilisateursApi
from .apis.villes_api import VillesApi

# import ApiClient
from .api_client import ApiClient

from .configuration import Configuration

configuration = Configuration()
