# coding: utf-8

"""
    Yanport API

    ## À propos Voici quelques ressources qui vous aideront à explorer notre API, si vous avez des problèmes ou des demandes, veuillez contacter le [support](mailto:support@yanport.com). ## REST API Nos services webs utilisent le protocle **HTTPS** sur le port 443, tout accès en HTTP sur le port 80 est bloqué par notre pare-feu. Les échanges de données sont réalisés en **JSON**. ## Authentification Avant de commencer à explorer notre API, vous devez nous [contacter](https://www.yanport.com/contact) afin d'obtenir un [JSON Web Token](https://jwt.io) (**JWT**) qui vous permettra de vous identifier à chaque requêtes. ### JWT (header) La méthode privilégiée pour s'authentifier est de passer à chaque requêtes le token dans le header `Authorization: Bearer {{ JWT }}` en remplaçant `{{ JWT }}` par votre token. ### JWT (query param) Il est aussi possible de passer le token directement en query param de la requête `https://api.yanport.com/?token={{ JWT }}`. (_privilégié le passage par header en production._) ## Pour démarrer Lorsque vous disposez de votre token d'authentification, vous pouvez commencer à explorer notre API grâce au boutton  `Try it out` sur chacun de nos webs services. Mais au préalable, vous devez vous authentifier en cliquant sur le boutton `Authorize `, en remplissant l'input `api_key` avec `Bearer {{ JWT }}`.  **Exemple** `Bearer eyUEkiLCJh...CHCUiBfD63oxoo=` ## Limitation Toutes les requêtes à notre API sont loggées, c'est pourquoi vous devez respecter nos [CGU](https://dev.yanport.com/cgu) afin d'éviter tout usage abusif de notre API. 

    OpenAPI spec version: 1.0
    Contact: dev@yanport.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into model package
from .ad import Ad
from .ad_ref import AdRef
from .address import Address
from .agency import Agency
from .agency_naf_code import AgencyNafCode
from .body import Body
from .body_1 import Body1
from .body_2 import Body2
from .bound_type import BoundType
from .building import Building
from .city import City
from .count_response import CountResponse
from .crawl_source import CrawlSource
from .customer import Customer
from .date_histogram import DateHistogram
from .date_histogram_point import DateHistogramPoint
from .dealer_sub_type import DealerSubType
from .dealer_type import DealerType
from .default_response import DefaultResponse
from .event_type import EventType
from .histogram import Histogram
from .histogram_point import HistogramPoint
from .inline_response_200 import InlineResponse200
from .inline_response_200_1 import InlineResponse2001
from .inline_response_200_2 import InlineResponse2002
from .inline_response_200_3 import InlineResponse2003
from .inline_response_200_4 import InlineResponse2004
from .inline_response_200_5 import InlineResponse2005
from .inline_response_200_6 import InlineResponse2006
from .inline_response_200_7 import InlineResponse2007
from .iris_quarter import IrisQuarter
from .lng_lat import LngLat
from .location import Location
from .mandatary_network import MandataryNetwork
from .marketing_dealer import MarketingDealer
from .marketing_type import MarketingType
from .model_property import ModelProperty
from .percentiles import Percentiles
from .percentiles_values import PercentilesValues
from .price_event import PriceEvent
from .property_building import PropertyBuilding
from .property_features import PropertyFeatures
from .property_features_additional_features import PropertyFeaturesAdditionalFeatures
from .property_features_condominium import PropertyFeaturesCondominium
from .property_features_construction import PropertyFeaturesConstruction
from .property_features_descriptive import PropertyFeaturesDescriptive
from .property_features_descriptive_equipments import PropertyFeaturesDescriptiveEquipments
from .property_features_descriptive_services import PropertyFeaturesDescriptiveServices
from .property_features_energy import PropertyFeaturesEnergy
from .property_features_geometry import PropertyFeaturesGeometry
from .property_features_geometry_areas import PropertyFeaturesGeometryAreas
from .property_features_geometry_floors import PropertyFeaturesGeometryFloors
from .property_features_visual import PropertyFeaturesVisual
from .property_marketing import PropertyMarketing
from .property_search_query import PropertySearchQuery
from .property_type import PropertyType
from .range import Range
from .rent_control import RentControl
from .rent_control_result import RentControlResult
from .rent_control_status import RentControlStatus
from .rent_control_zone import RentControlZone
from .room import Room
from .search_query_param import SearchQueryParam
from .sections import Sections
from .sections_conclusion import SectionsConclusion
from .sections_estimation_engine import SectionsEstimationEngine
from .sections_estimation_engine_zones import SectionsEstimationEngineZones
from .sections_market_stats import SectionsMarketStats
from .sections_property_price_study import SectionsPropertyPriceStudy
from .sections_similar_properties import SectionsSimilarProperties
from .state import State
from .stats import Stats
from .stock_evolution import StockEvolution
from .stock_evolution_point import StockEvolutionPoint
from .study import Study
from .user import User
from .user_user_preference import UserUserPreference
from .user_user_preference_commercial_zone import UserUserPreferenceCommercialZone
